InotifyEventMask

Struct InotifyEventMask 

pub struct InotifyEventMask(/* private fields */);
Masque d’événements / d’options inotify (IN_*). Noms kernel conservés (ADR-029). Sert à la fois en entrée (add_watch) et en sortie (bits positionnés par le kernel dans l’événement lu).

Implementations

Source

impl InotifyEventMask

pub const ACCESS: Self

Fichier accédé (lecture).

pub const MODIFY: Self

Fichier modifié (écriture).

pub const ATTRIB: Self

Métadonnées changées (permissions, horodatage…).

pub const CLOSE_WRITE: Self

Fichier ouvert en écriture fermé.

pub const CLOSE_NOWRITE: Self

Fichier ouvert en lecture seule fermé.

pub const OPEN: Self

Fichier ouvert.

pub const MOVED_FROM: Self

Fichier déplacé hors du répertoire surveillé (corrèle par cookie).

pub const MOVED_TO: Self

Fichier déplacé dans le répertoire surveillé (corrèle par cookie).

pub const CREATE: Self

Fichier/répertoire créé.

pub const DELETE: Self

Fichier/répertoire supprimé.

pub const DELETE_SELF: Self

Le répertoire/fichier surveillé lui-même a été supprimé.

pub const MOVE_SELF: Self

Le répertoire/fichier surveillé lui-même a été déplacé.

pub const UNMOUNT: Self

Le système de fichiers contenant l’objet surveillé a été démonté (positionné par le kernel).

pub const Q_OVERFLOW: Self

La file d’événements a débordé (positionné par le kernel ; wd = -1).

pub const IGNORED: Self

Le watch a été retiré (explicitement, ou objet supprimé/démonté).

pub const ISDIR: Self

L’objet de l’événement est un répertoire (positionné par le kernel).

pub const ONLYDIR: Self

Option : ne surveiller que si path est un répertoire.

pub const DONT_FOLLOW: Self

Option : ne pas déréférencer path s’il est un lien symbolique.

Option : exclure les événements des fichiers déjà unlinkés.

pub const MASK_ADD: Self

Option : ajouter à (au lieu de remplacer) le masque d’un watch existant.

pub const ONESHOT: Self

Option : surveiller une seule fois puis retirer le watch.

Source

impl InotifyEventMask

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Self)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Self) -> Self

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl InotifyEventMask

pub const fn iter(&self) -> Iter<InotifyEventMask>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<InotifyEventMask>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.