pub struct SetupFlags(/* private fields */);Expand description
Flags de io_uring_setup(2) (axe A, 17 flags en 6.12).
Appliqués via IoUringBuilder. Deux flags de l’axe A ne figurent pas
ici car exposés par des méthodes du builder : CQSIZE
(with_completion_queue_entries) et ATTACH_WQ (attach_work_queue).
Implementations
Sourceimpl SetupFlags
impl SetupFlags
Sourcepub const R_DISABLED: Self
pub const R_DISABLED: Self
IORING_SETUP_R_DISABLED : ring créé désactivé (primitive sandbox, Temps 3f).
Sourcepub const SUBMIT_ALL: Self
pub const SUBMIT_ALL: Self
IORING_SETUP_SUBMIT_ALL : ne pas s’arrêter à la première erreur de soumission.
Sourcepub const COOP_TASKRUN: Self
pub const COOP_TASKRUN: Self
IORING_SETUP_COOP_TASKRUN : task-work coopératif (moins d’IPI).
Sourcepub const TASKRUN_FLAG: Self
pub const TASKRUN_FLAG: Self
IORING_SETUP_TASKRUN_FLAG : signale le task-work en attente via un flag d’anneau.
Sourcepub const SINGLE_ISSUER: Self
pub const SINGLE_ISSUER: Self
IORING_SETUP_SINGLE_ISSUER : un seul thread soumetteur (recommandé Air).
Sourcepub const DEFER_TASKRUN: Self
pub const DEFER_TASKRUN: Self
IORING_SETUP_DEFER_TASKRUN : task-work différé à GETEVENTS (latence basse).
Sourcepub const NO_MMAP: Self
pub const NO_MMAP: Self
IORING_SETUP_NO_MMAP : mémoire des anneaux fournie par l’appelant (avancé, gated).
Sourcepub const REGISTERED_FD_ONLY: Self
pub const REGISTERED_FD_ONLY: Self
IORING_SETUP_REGISTERED_FD_ONLY : ring fd uniquement enregistré.
Sourcepub const NO_SQARRAY: Self
pub const NO_SQARRAY: Self
IORING_SETUP_NO_SQARRAY : supprime l’indirection du tableau d’index SQ.
Sourceimpl SetupFlags
impl SetupFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SetupFlags
impl SetupFlags
Sourcepub const fn iter(&self) -> Iter<SetupFlags>
pub const fn iter(&self) -> Iter<SetupFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SetupFlags>
pub const fn iter_names(&self) -> IterNames<SetupFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.