pub struct LandlockAccessFs(/* private fields */);Expand description
Permissions filesystem Landlock (cf. linux/landlock.h).
La disponibilité de certains bits dépend de la version ABI Landlock
du kernel. Utilisez landlock_supported_abi() pour connaître la
version disponible et masquer les bits non supportés.
| Bit | Depuis | Signification |
|---|---|---|
| EXECUTE … MAKE_SYM | Landlock v1 (Linux 5.13) | permissions de base |
| REFER | Landlock v2 (Linux 5.19) | déplacement inter-répertoires |
| TRUNCATE | Landlock v3 (Linux 6.2) | troncature de fichiers |
| IOCTL_DEV | Landlock v5 (Linux 6.10) | ioctl sur devices |
Implementations
Sourceimpl LandlockAccessFs
impl LandlockAccessFs
Sourcepub const WRITE_FILE: Self
pub const WRITE_FILE: Self
Écriture dans les fichiers (pas troncature : voir TRUNCATE).
Sourcepub const REMOVE_DIR: Self
pub const REMOVE_DIR: Self
Suppression de répertoires.
Sourcepub const REMOVE_FILE: Self
pub const REMOVE_FILE: Self
Suppression de fichiers.
Sourcepub const MAKE_BLOCK: Self
pub const MAKE_BLOCK: Self
Création de fichiers bloc.
Sourceimpl LandlockAccessFs
impl LandlockAccessFs
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl LandlockAccessFs
impl LandlockAccessFs
Sourcepub const fn iter(&self) -> Iter<LandlockAccessFs>
pub const fn iter(&self) -> Iter<LandlockAccessFs>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<LandlockAccessFs>
pub const fn iter_names(&self) -> IterNames<LandlockAccessFs>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.