pub struct InotifyEventMask(/* private fields */);Expand description
Masque d’événements / d’options inotify (IN_*). Noms kernel conservés
(ADR-029). Sert à la fois en entrée (add_watch) et en sortie
(bits positionnés par le kernel dans l’événement lu).
Implementations
Sourceimpl InotifyEventMask
impl InotifyEventMask
Sourcepub const CLOSE_WRITE: Self
pub const CLOSE_WRITE: Self
Fichier ouvert en écriture fermé.
Sourcepub const CLOSE_NOWRITE: Self
pub const CLOSE_NOWRITE: Self
Fichier ouvert en lecture seule fermé.
Sourcepub const MOVED_FROM: Self
pub const MOVED_FROM: Self
Fichier déplacé hors du répertoire surveillé (corrèle par cookie).
Sourcepub const DELETE_SELF: Self
pub const DELETE_SELF: Self
Le répertoire/fichier surveillé lui-même a été supprimé.
Sourcepub const UNMOUNT: Self
pub const UNMOUNT: Self
Le système de fichiers contenant l’objet surveillé a été démonté (positionné par le kernel).
Sourcepub const Q_OVERFLOW: Self
pub const Q_OVERFLOW: Self
La file d’événements a débordé (positionné par le kernel ; wd = -1).
Sourcepub const DONT_FOLLOW: Self
pub const DONT_FOLLOW: Self
Option : ne pas déréférencer path s’il est un lien symbolique.
Sourcepub const EXCL_UNLINK: Self
pub const EXCL_UNLINK: Self
Option : exclure les événements des fichiers déjà unlinkés.
Sourceimpl InotifyEventMask
impl InotifyEventMask
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl InotifyEventMask
impl InotifyEventMask
Sourcepub const fn iter(&self) -> Iter<InotifyEventMask>
pub const fn iter(&self) -> Iter<InotifyEventMask>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<InotifyEventMask>
pub const fn iter_names(&self) -> IterNames<InotifyEventMask>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.